from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from .accounts_api import AccountsApi
from .activity_types_api import ActivityTypesApi
from .closing_statuses_api import ClosingStatusesApi
from .contact_sides_api import ContactSidesApi
from .countries_api import CountriesApi
from .currencies_api import CurrenciesApi
from .documents_api import DocumentsApi
from .e_sign_permission_profiles_api import ESignPermissionProfilesApi
from .external_form_fill_sessions_api import ExternalFormFillSessionsApi
from .fields_api import FieldsApi
from .financing_types_api import FinancingTypesApi
from .form_details_api import FormDetailsApi
from .form_groups_api import FormGroupsApi
from .form_libraries_api import FormLibrariesApi
from .offices_api import OfficesApi
from .origins_of_leads_api import OriginsOfLeadsApi
from .property_types_api import PropertyTypesApi
from .regions_api import RegionsApi
from .roles_api import RolesApi
from .room_contact_types_api import RoomContactTypesApi
from .room_folders_api import RoomFoldersApi
from .room_templates_api import RoomTemplatesApi
from .rooms_api import RoomsApi
from .seller_decision_types_api import SellerDecisionTypesApi
from .special_circumstance_types_api import SpecialCircumstanceTypesApi
from .states_api import StatesApi
from .task_date_types_api import TaskDateTypesApi
from .task_list_templates_api import TaskListTemplatesApi
from .task_lists_api import TaskListsApi
from .task_responsibility_types_api import TaskResponsibilityTypesApi
from .task_statuses_api import TaskStatusesApi
from .time_zones_api import TimeZonesApi
from .transaction_sides_api import TransactionSidesApi
from .users_api import UsersApi



# coding: utf-8

# flake8: noqa

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
"""

from __future__ import absolute_import

import base64
import os
import unittest

from docusign_rooms.client.api_client import ApiClient
from docusign_rooms.client.auth.oauth import OAuthToken


class TestConfig(object):
    def __init__(self, user_name=None, client_secret =None, user_id=None, integrator_key=None, host=None, recipient_email=None,
                 recipient_name=None, template_role_name=None, template_id=None, return_url=None, redirect_uri=None):
        self.user_name = user_name if user_name else os.environ.get("USER_NAME")
        self.client_secret = client_secret if client_secret else os.environ.get("CLIENT_SECRET")
        self.integrator_key = integrator_key if integrator_key else os.environ.get("INTEGRATOR_KEY_JWT")
        self.host = host if host else "https://demo.rooms.docusign.com/restapi"
        self.recipient_email = recipient_email if recipient_email else os.environ.get("USER_NAME")
        self.recipient_name = recipient_name if recipient_name else os.environ.get("USER_NAME")
        self.template_role_name = template_role_name if template_role_name else os.environ.get("USER_NAME")
        self.template_id = template_id if template_id else os.environ.get("TEMPLATE_ID")
        self.return_url = return_url if return_url else os.environ.get("REDIRECT_URI")
        self.user_id = user_id if user_id else os.environ.get("USER_ID")
        self.redirect_uri = redirect_uri if redirect_uri else os.environ.get("REDIRECT_URI")

        self.oauth_host_name = "account-d.docusign.com"
        self.private_key_bytes = base64.b64decode(os.environ.get("PRIVATE_KEY"))
        self.expires_in = 3600


class TestOauth(unittest.TestCase):
    """ AccountBillingPlan unit test stubs """

    def setUp(self):
        self.test_config = TestConfig()
        self.api_client = ApiClient(oauth_host_name=self.test_config.oauth_host_name)
        self.api_client.set_base_path("https://demo.rooms.docusign.com")
        self.api_client.set_oauth_host_name(self.test_config.oauth_host_name)

    def test_oauth_uri(self):
        self.api_client.get_oauth_host_name()
        uri = self.api_client.get_authorization_uri(client_id=self.test_config.integrator_key,
                                                redirect_uri=self.test_config.redirect_uri,
                                                    scopes=["signature", "impersonation",
                                                            "dtr.rooms.read", "dtr.rooms.write",
                                                            "dtr.company.read", "dtr.company.write"],
                                                response_type='code')
        self.assertTrue(isinstance(uri, str))
        self.api_client.rest_client.pool_manager.clear()

    def test_jwt_application(self):
        token_obj = self.api_client.request_jwt_application_token(client_id=self.test_config.integrator_key,
                                                           oauth_host_name=self.test_config.oauth_host_name,
                                                           private_key_bytes=self.test_config.private_key_bytes,
                                                           expires_in=self.test_config.expires_in)
        self.assertTrue(isinstance(token_obj, OAuthToken))
        self.api_client.rest_client.pool_manager.clear()

    def test_jwt_user(self):
        token_obj = self.api_client.request_jwt_user_token(client_id=self.test_config.integrator_key,
                                                           user_id=self.test_config.user_id,
                                                           oauth_host_name=self.api_client.get_oauth_host_name(),
                                                           private_key_bytes=self.test_config.private_key_bytes,
                                                           expires_in=self.test_config.expires_in
                                                           )
        self.assertTrue(isinstance(token_obj, OAuthToken))
        self.api_client.rest_client.pool_manager.clear()

    def test_authorization_code_login(self):
        self.api_client.get_oauth_host_name()
        uri = self.api_client.get_authorization_uri(client_id=self.test_config.integrator_key,
                                                    redirect_uri=self.test_config.redirect_uri,
                                                    scopes=["signature"],
                                                    response_type='code')
        self.assertTrue(isinstance(uri, str))
        self.api_client.rest_client.pool_manager.clear()


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..client.configuration import Configuration
from ..client.api_client import ApiClient


class RoomsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def add_document_to_room(self, room_id, document, account_id, **kwargs):
        """
        Add a document to a room.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.add_document_to_room(room_id, document, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id:  (required)
        :param Document document:  (required)
        :param str account_id: (required)
        :return: RoomDocument
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.add_document_to_room_with_http_info(room_id, document, account_id, **kwargs)
        else:
            (data) = self.add_document_to_room_with_http_info(room_id, document, account_id, **kwargs)
            return data

    def add_document_to_room_with_http_info(self, room_id, document, account_id, **kwargs):
        """
        Add a document to a room.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.add_document_to_room_with_http_info(room_id, document, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id:  (required)
        :param Document document:  (required)
        :param str account_id: (required)
        :return: RoomDocument
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['room_id', 'document', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_document_to_room" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'room_id' is set
        if ('room_id' not in params) or (params['room_id'] is None):
            raise ValueError("Missing the required parameter `room_id` when calling `add_document_to_room`")
        # verify the required parameter 'document' is set
        if ('document' not in params) or (params['document'] is None):
            raise ValueError("Missing the required parameter `document` when calling `add_document_to_room`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `add_document_to_room`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/rooms/{roomId}/documents'.replace('{format}', 'json')
        path_params = {}
        if 'room_id' in params:
            path_params['roomId'] = params['room_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'document' in params:
            body_params = params['document']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='RoomDocument',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def add_document_to_room_via_file_upload(self, room_id, account_id, file, **kwargs):
        """
        Add a document to a room via file contents upload.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.add_document_to_room_via_file_upload(room_id, account_id, file, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id:  (required)
        :param str account_id: (required)
        :param file file: (required)
        :return: RoomDocument
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.add_document_to_room_via_file_upload_with_http_info(room_id, account_id, file, **kwargs)
        else:
            (data) = self.add_document_to_room_via_file_upload_with_http_info(room_id, account_id, file, **kwargs)
            return data

    def add_document_to_room_via_file_upload_with_http_info(self, room_id, account_id, file, **kwargs):
        """
        Add a document to a room via file contents upload.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.add_document_to_room_via_file_upload_with_http_info(room_id, account_id, file, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id:  (required)
        :param str account_id: (required)
        :param file file: (required)
        :return: RoomDocument
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['room_id', 'account_id', 'file']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_document_to_room_via_file_upload" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'room_id' is set
        if ('room_id' not in params) or (params['room_id'] is None):
            raise ValueError("Missing the required parameter `room_id` when calling `add_document_to_room_via_file_upload`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `add_document_to_room_via_file_upload`")
        # verify the required parameter 'file' is set
        if ('file' not in params) or (params['file'] is None):
            raise ValueError("Missing the required parameter `file` when calling `add_document_to_room_via_file_upload`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/rooms/{roomId}/documents/contents'.replace('{format}', 'json')
        path_params = {}
        if 'room_id' in params:
            path_params['roomId'] = params['room_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'file' in params:
            local_var_files['file'] = params['file']

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/form-data'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='RoomDocument',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def add_form_to_room(self, room_id, form_for_add, account_id, **kwargs):
        """
        Adds a DocuSign Form to a room
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.add_form_to_room(room_id, form_for_add, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id: Id of the room to which the DocuSign Form is being added (required)
        :param FormForAdd form_for_add: Contains information about the form being added (required)
        :param str account_id: (required)
        :return: RoomDocument
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.add_form_to_room_with_http_info(room_id, form_for_add, account_id, **kwargs)
        else:
            (data) = self.add_form_to_room_with_http_info(room_id, form_for_add, account_id, **kwargs)
            return data

    def add_form_to_room_with_http_info(self, room_id, form_for_add, account_id, **kwargs):
        """
        Adds a DocuSign Form to a room
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.add_form_to_room_with_http_info(room_id, form_for_add, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id: Id of the room to which the DocuSign Form is being added (required)
        :param FormForAdd form_for_add: Contains information about the form being added (required)
        :param str account_id: (required)
        :return: RoomDocument
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['room_id', 'form_for_add', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_form_to_room" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'room_id' is set
        if ('room_id' not in params) or (params['room_id'] is None):
            raise ValueError("Missing the required parameter `room_id` when calling `add_form_to_room`")
        # verify the required parameter 'form_for_add' is set
        if ('form_for_add' not in params) or (params['form_for_add'] is None):
            raise ValueError("Missing the required parameter `form_for_add` when calling `add_form_to_room`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `add_form_to_room`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/rooms/{roomId}/forms'.replace('{format}', 'json')
        path_params = {}
        if 'room_id' in params:
            path_params['roomId'] = params['room_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'form_for_add' in params:
            body_params = params['form_for_add']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='RoomDocument',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def create_room(self, room_for_create, account_id, **kwargs):
        """
        Creates a new Room
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_room(room_for_create, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param RoomForCreate room_for_create: The properties of the new room (required)
        :param str account_id: (required)
        :return: Room
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_room_with_http_info(room_for_create, account_id, **kwargs)
        else:
            (data) = self.create_room_with_http_info(room_for_create, account_id, **kwargs)
            return data

    def create_room_with_http_info(self, room_for_create, account_id, **kwargs):
        """
        Creates a new Room
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_room_with_http_info(room_for_create, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param RoomForCreate room_for_create: The properties of the new room (required)
        :param str account_id: (required)
        :return: Room
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['room_for_create', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_room" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'room_for_create' is set
        if ('room_for_create' not in params) or (params['room_for_create'] is None):
            raise ValueError("Missing the required parameter `room_for_create` when calling `create_room`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `create_room`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/rooms'.replace('{format}', 'json')
        path_params = {}
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'room_for_create' in params:
            body_params = params['room_for_create']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Room',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def delete_room(self, room_id, account_id, **kwargs):
        """
        Deletes the room having the given room ID.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_room(room_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id: ID of the room to be deleted. (required)
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.delete_room_with_http_info(room_id, account_id, **kwargs)
        else:
            (data) = self.delete_room_with_http_info(room_id, account_id, **kwargs)
            return data

    def delete_room_with_http_info(self, room_id, account_id, **kwargs):
        """
        Deletes the room having the given room ID.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_room_with_http_info(room_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id: ID of the room to be deleted. (required)
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['room_id', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_room" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'room_id' is set
        if ('room_id' not in params) or (params['room_id'] is None):
            raise ValueError("Missing the required parameter `room_id` when calling `delete_room`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `delete_room`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/rooms/{roomId}'.replace('{format}', 'json')
        path_params = {}
        if 'room_id' in params:
            path_params['roomId'] = params['room_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_assignable_roles(self, room_id, account_id, **kwargs):
        """
        Returns the roles for which the calling user, based on their role within the room, can assign to invitees.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_assignable_roles(room_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id:  (required)
        :param str account_id: (required)
        :param str assignee_email: Optional parameter indicating to only return roles (internal/external) assignable to this user.
        :param str filter: 
        :param int start_position: 
        :param int count: 
        :return: AssignableRoles
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_assignable_roles_with_http_info(room_id, account_id, **kwargs)
        else:
            (data) = self.get_assignable_roles_with_http_info(room_id, account_id, **kwargs)
            return data

    def get_assignable_roles_with_http_info(self, room_id, account_id, **kwargs):
        """
        Returns the roles for which the calling user, based on their role within the room, can assign to invitees.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_assignable_roles_with_http_info(room_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id:  (required)
        :param str account_id: (required)
        :param str assignee_email: Optional parameter indicating to only return roles (internal/external) assignable to this user.
        :param str filter: 
        :param int start_position: 
        :param int count: 
        :return: AssignableRoles
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['room_id', 'account_id', 'assignee_email', 'filter', 'start_position', 'count']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_assignable_roles" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'room_id' is set
        if ('room_id' not in params) or (params['room_id'] is None):
            raise ValueError("Missing the required parameter `room_id` when calling `get_assignable_roles`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `get_assignable_roles`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/rooms/{roomId}/assignable_roles'.replace('{format}', 'json')
        path_params = {}
        if 'room_id' in params:
            path_params['roomId'] = params['room_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}
        if 'assignee_email' in params:
            query_params['assigneeEmail'] = params['assignee_email']
        if 'filter' in params:
            query_params['filter'] = params['filter']
        if 'start_position' in params:
            query_params['startPosition'] = params['start_position']
        if 'count' in params:
            query_params['count'] = params['count']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='AssignableRoles',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_documents(self, room_id, account_id, **kwargs):
        """
        Get documents in the room accessible to the calling user.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_documents(room_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id:  (required)
        :param str account_id: (required)
        :param int count: Number of documents to return. Defaults to the maximum which is 100.
        :param int start_position: Position of the first item in the total results. Defaults to 0.
        :return: RoomDocumentList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_documents_with_http_info(room_id, account_id, **kwargs)
        else:
            (data) = self.get_documents_with_http_info(room_id, account_id, **kwargs)
            return data

    def get_documents_with_http_info(self, room_id, account_id, **kwargs):
        """
        Get documents in the room accessible to the calling user.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_documents_with_http_info(room_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id:  (required)
        :param str account_id: (required)
        :param int count: Number of documents to return. Defaults to the maximum which is 100.
        :param int start_position: Position of the first item in the total results. Defaults to 0.
        :return: RoomDocumentList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['room_id', 'account_id', 'count', 'start_position']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_documents" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'room_id' is set
        if ('room_id' not in params) or (params['room_id'] is None):
            raise ValueError("Missing the required parameter `room_id` when calling `get_documents`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `get_documents`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/rooms/{roomId}/documents'.replace('{format}', 'json')
        path_params = {}
        if 'room_id' in params:
            path_params['roomId'] = params['room_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}
        if 'count' in params:
            query_params['count'] = params['count']
        if 'start_position' in params:
            query_params['startPosition'] = params['start_position']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='RoomDocumentList',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_room(self, room_id, account_id, **kwargs):
        """
        Gets information about the given room.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_room(room_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id:  (required)
        :param str account_id: (required)
        :param bool include_field_data: Indicates if field data (a.k.a., room details) should be included in the response. Defaults to false.
        :return: Room
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_room_with_http_info(room_id, account_id, **kwargs)
        else:
            (data) = self.get_room_with_http_info(room_id, account_id, **kwargs)
            return data

    def get_room_with_http_info(self, room_id, account_id, **kwargs):
        """
        Gets information about the given room.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_room_with_http_info(room_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id:  (required)
        :param str account_id: (required)
        :param bool include_field_data: Indicates if field data (a.k.a., room details) should be included in the response. Defaults to false.
        :return: Room
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['room_id', 'account_id', 'include_field_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_room" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'room_id' is set
        if ('room_id' not in params) or (params['room_id'] is None):
            raise ValueError("Missing the required parameter `room_id` when calling `get_room`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `get_room`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/rooms/{roomId}'.replace('{format}', 'json')
        path_params = {}
        if 'room_id' in params:
            path_params['roomId'] = params['room_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}
        if 'include_field_data' in params:
            query_params['includeFieldData'] = params['include_field_data']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Room',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_room_field_data(self, room_id, account_id, **kwargs):
        """
        Returns the FieldData associated with the provided roomId.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_room_field_data(room_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id:  (required)
        :param str account_id: (required)
        :return: FieldData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_room_field_data_with_http_info(room_id, account_id, **kwargs)
        else:
            (data) = self.get_room_field_data_with_http_info(room_id, account_id, **kwargs)
            return data

    def get_room_field_data_with_http_info(self, room_id, account_id, **kwargs):
        """
        Returns the FieldData associated with the provided roomId.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_room_field_data_with_http_info(room_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id:  (required)
        :param str account_id: (required)
        :return: FieldData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['room_id', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_room_field_data" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'room_id' is set
        if ('room_id' not in params) or (params['room_id'] is None):
            raise ValueError("Missing the required parameter `room_id` when calling `get_room_field_data`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `get_room_field_data`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/rooms/{roomId}/field_data'.replace('{format}', 'json')
        path_params = {}
        if 'room_id' in params:
            path_params['roomId'] = params['room_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='FieldData',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_room_field_set(self, room_id, account_id, **kwargs):
        """
        Gets the field set associated with the room.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_room_field_set(room_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id:  (required)
        :param str account_id: (required)
        :return: FieldSet
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_room_field_set_with_http_info(room_id, account_id, **kwargs)
        else:
            (data) = self.get_room_field_set_with_http_info(room_id, account_id, **kwargs)
            return data

    def get_room_field_set_with_http_info(self, room_id, account_id, **kwargs):
        """
        Gets the field set associated with the room.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_room_field_set_with_http_info(room_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id:  (required)
        :param str account_id: (required)
        :return: FieldSet
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['room_id', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_room_field_set" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'room_id' is set
        if ('room_id' not in params) or (params['room_id'] is None):
            raise ValueError("Missing the required parameter `room_id` when calling `get_room_field_set`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `get_room_field_set`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/rooms/{roomId}/field_set'.replace('{format}', 'json')
        path_params = {}
        if 'room_id' in params:
            path_params['roomId'] = params['room_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='FieldSet',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_room_users(self, room_id, account_id, **kwargs):
        """
        Retrieves the list of users in the given room.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_room_users(room_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id:  (required)
        :param str account_id: (required)
        :param int count: Number of room users to return. Defaults to the maximum which is 100.
        :param int start_position: Position of the first item in the total results. Defaults to 0.
        :param str filter: Returns room users filtered by Name and Email.
        :param str sort: Sorts results. Options are FirstNameAsc, FirstNameDesc, LastNameAsc, LastNameDesc, EmailAsc, EmailDesc. Defaults to LastNameDesc
        :return: RoomUsersResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_room_users_with_http_info(room_id, account_id, **kwargs)
        else:
            (data) = self.get_room_users_with_http_info(room_id, account_id, **kwargs)
            return data

    def get_room_users_with_http_info(self, room_id, account_id, **kwargs):
        """
        Retrieves the list of users in the given room.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_room_users_with_http_info(room_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id:  (required)
        :param str account_id: (required)
        :param int count: Number of room users to return. Defaults to the maximum which is 100.
        :param int start_position: Position of the first item in the total results. Defaults to 0.
        :param str filter: Returns room users filtered by Name and Email.
        :param str sort: Sorts results. Options are FirstNameAsc, FirstNameDesc, LastNameAsc, LastNameDesc, EmailAsc, EmailDesc. Defaults to LastNameDesc
        :return: RoomUsersResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['room_id', 'account_id', 'count', 'start_position', 'filter', 'sort']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_room_users" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'room_id' is set
        if ('room_id' not in params) or (params['room_id'] is None):
            raise ValueError("Missing the required parameter `room_id` when calling `get_room_users`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `get_room_users`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/rooms/{roomId}/users'.replace('{format}', 'json')
        path_params = {}
        if 'room_id' in params:
            path_params['roomId'] = params['room_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}
        if 'count' in params:
            query_params['count'] = params['count']
        if 'start_position' in params:
            query_params['startPosition'] = params['start_position']
        if 'filter' in params:
            query_params['filter'] = params['filter']
        if 'sort' in params:
            query_params['sort'] = params['sort']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='RoomUsersResult',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_rooms(self, account_id, **kwargs):
        """
        Gets rooms available to the calling user.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_rooms(account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str account_id: (required)
        :param int count: Number of rooms to return. Defaults to the maximum which is 100.
        :param int start_position: Position of the first item in the total results. Defaults to 0.
        :param str room_status: Status of the rooms to return. Defaults to \"Active\".
        :param int office_id: Only return rooms in this office.
        :param str field_data_changed_start_date: Fields data changed start datetime in UTC. Valid formats: yyyy-mm-dd hh:mm:ss or yyyy/mm/dd hh:mm:ss -Time is optional and will default to 00:00:00.
        :param str field_data_changed_end_date: Fields-data changed end DateTime in UTC. Valid formats: yyyy-mm-dd hh:mm:ss or yyyy/mm/dd hh:mm:ss -Time is optional and will default to 00:00:00.
        :param str room_closed_start_date: Room closed start datetime in UTC. Valid formats: yyyy-mm-dd hh:mm:ss or yyyy/mm/dd hh:mm:ss -Time is optional and will default to 00:00:00.
        :param str room_closed_end_date: Room closed end datetime in UTC. Valid formats: yyyy-mm-dd hh:mm:ss or yyyy/mm/dd hh:mm:ss -Time is optional and will default to 00:00:00.
        :return: RoomSummaryList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_rooms_with_http_info(account_id, **kwargs)
        else:
            (data) = self.get_rooms_with_http_info(account_id, **kwargs)
            return data

    def get_rooms_with_http_info(self, account_id, **kwargs):
        """
        Gets rooms available to the calling user.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_rooms_with_http_info(account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str account_id: (required)
        :param int count: Number of rooms to return. Defaults to the maximum which is 100.
        :param int start_position: Position of the first item in the total results. Defaults to 0.
        :param str room_status: Status of the rooms to return. Defaults to \"Active\".
        :param int office_id: Only return rooms in this office.
        :param str field_data_changed_start_date: Fields data changed start datetime in UTC. Valid formats: yyyy-mm-dd hh:mm:ss or yyyy/mm/dd hh:mm:ss -Time is optional and will default to 00:00:00.
        :param str field_data_changed_end_date: Fields-data changed end DateTime in UTC. Valid formats: yyyy-mm-dd hh:mm:ss or yyyy/mm/dd hh:mm:ss -Time is optional and will default to 00:00:00.
        :param str room_closed_start_date: Room closed start datetime in UTC. Valid formats: yyyy-mm-dd hh:mm:ss or yyyy/mm/dd hh:mm:ss -Time is optional and will default to 00:00:00.
        :param str room_closed_end_date: Room closed end datetime in UTC. Valid formats: yyyy-mm-dd hh:mm:ss or yyyy/mm/dd hh:mm:ss -Time is optional and will default to 00:00:00.
        :return: RoomSummaryList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['account_id', 'count', 'start_position', 'room_status', 'office_id', 'field_data_changed_start_date', 'field_data_changed_end_date', 'room_closed_start_date', 'room_closed_end_date']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_rooms" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `get_rooms`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/rooms'.replace('{format}', 'json')
        path_params = {}
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}
        if 'count' in params:
            query_params['count'] = params['count']
        if 'start_position' in params:
            query_params['startPosition'] = params['start_position']
        if 'room_status' in params:
            query_params['roomStatus'] = params['room_status']
        if 'office_id' in params:
            query_params['officeId'] = params['office_id']
        if 'field_data_changed_start_date' in params:
            query_params['fieldDataChangedStartDate'] = params['field_data_changed_start_date']
        if 'field_data_changed_end_date' in params:
            query_params['fieldDataChangedEndDate'] = params['field_data_changed_end_date']
        if 'room_closed_start_date' in params:
            query_params['roomClosedStartDate'] = params['room_closed_start_date']
        if 'room_closed_end_date' in params:
            query_params['roomClosedEndDate'] = params['room_closed_end_date']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='RoomSummaryList',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def invite_user(self, room_id, room_invite_request, account_id, **kwargs):
        """
        Invites a user to the room by email address.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.invite_user(room_id, room_invite_request, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id: (required)
        :param RoomInvite room_invite_request: (required)
        :param str account_id: (required)
        :return: RoomInviteResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.invite_user_with_http_info(room_id, room_invite_request, account_id, **kwargs)
        else:
            (data) = self.invite_user_with_http_info(room_id, room_invite_request, account_id, **kwargs)
            return data

    def invite_user_with_http_info(self, room_id, room_invite_request, account_id, **kwargs):
        """
        Invites a user to the room by email address.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.invite_user_with_http_info(room_id, room_invite_request, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id: (required)
        :param RoomInvite room_invite_request: (required)
        :param str account_id: (required)
        :return: RoomInviteResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['room_id', 'room_invite_request', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invite_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'room_id' is set
        if ('room_id' not in params) or (params['room_id'] is None):
            raise ValueError("Missing the required parameter `room_id` when calling `invite_user`")
        # verify the required parameter 'room_invite_request' is set
        if ('room_invite_request' not in params) or (params['room_invite_request'] is None):
            raise ValueError("Missing the required parameter `room_invite_request` when calling `invite_user`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `invite_user`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/rooms/{roomId}/users'.replace('{format}', 'json')
        path_params = {}
        if 'room_id' in params:
            path_params['roomId'] = params['room_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'room_invite_request' in params:
            body_params = params['room_invite_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='RoomInviteResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def put_room_user(self, room_id, user_id, room_user_for_update, account_id, **kwargs):
        """
        Updates the specified user's role and transaction side.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_room_user(room_id, user_id, room_user_for_update, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id: (required)
        :param int user_id: (required)
        :param RoomUserForUpdate room_user_for_update: (required)
        :param str account_id: (required)
        :return: RoomUser
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.put_room_user_with_http_info(room_id, user_id, room_user_for_update, account_id, **kwargs)
        else:
            (data) = self.put_room_user_with_http_info(room_id, user_id, room_user_for_update, account_id, **kwargs)
            return data

    def put_room_user_with_http_info(self, room_id, user_id, room_user_for_update, account_id, **kwargs):
        """
        Updates the specified user's role and transaction side.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_room_user_with_http_info(room_id, user_id, room_user_for_update, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id: (required)
        :param int user_id: (required)
        :param RoomUserForUpdate room_user_for_update: (required)
        :param str account_id: (required)
        :return: RoomUser
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['room_id', 'user_id', 'room_user_for_update', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_room_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'room_id' is set
        if ('room_id' not in params) or (params['room_id'] is None):
            raise ValueError("Missing the required parameter `room_id` when calling `put_room_user`")
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params) or (params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `put_room_user`")
        # verify the required parameter 'room_user_for_update' is set
        if ('room_user_for_update' not in params) or (params['room_user_for_update'] is None):
            raise ValueError("Missing the required parameter `room_user_for_update` when calling `put_room_user`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `put_room_user`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/rooms/{roomId}/users/{userId}'.replace('{format}', 'json')
        path_params = {}
        if 'room_id' in params:
            path_params['roomId'] = params['room_id']
        if 'user_id' in params:
            path_params['userId'] = params['user_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'room_user_for_update' in params:
            body_params = params['room_user_for_update']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='RoomUser',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def restore_room_user_access(self, room_id, user_id, account_id, **kwargs):
        """
        Restores the specified user's access to the room.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.restore_room_user_access(room_id, user_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id: The room Id to restore access (required)
        :param int user_id: The user Id getting restored to the room (required)
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.restore_room_user_access_with_http_info(room_id, user_id, account_id, **kwargs)
        else:
            (data) = self.restore_room_user_access_with_http_info(room_id, user_id, account_id, **kwargs)
            return data

    def restore_room_user_access_with_http_info(self, room_id, user_id, account_id, **kwargs):
        """
        Restores the specified user's access to the room.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.restore_room_user_access_with_http_info(room_id, user_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id: The room Id to restore access (required)
        :param int user_id: The user Id getting restored to the room (required)
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['room_id', 'user_id', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method restore_room_user_access" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'room_id' is set
        if ('room_id' not in params) or (params['room_id'] is None):
            raise ValueError("Missing the required parameter `room_id` when calling `restore_room_user_access`")
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params) or (params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `restore_room_user_access`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `restore_room_user_access`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/rooms/{roomId}/users/{userId}/restore_access'.replace('{format}', 'json')
        path_params = {}
        if 'room_id' in params:
            path_params['roomId'] = params['room_id']
        if 'user_id' in params:
            path_params['userId'] = params['user_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def revoke_room_user_access(self, room_id, user_id, account_id, **kwargs):
        """
        Revokes the specified user's access to the room.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.revoke_room_user_access(room_id, user_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id: The room Id to revoke access from (required)
        :param int user_id: The user Id getting revoked from the room (required)
        :param RoomUserRemovalDetail room_user_removal_detail: Contains the date on which the users room access should be revoked
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.revoke_room_user_access_with_http_info(room_id, user_id, account_id, **kwargs)
        else:
            (data) = self.revoke_room_user_access_with_http_info(room_id, user_id, account_id, **kwargs)
            return data

    def revoke_room_user_access_with_http_info(self, room_id, user_id, account_id, **kwargs):
        """
        Revokes the specified user's access to the room.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.revoke_room_user_access_with_http_info(room_id, user_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id: The room Id to revoke access from (required)
        :param int user_id: The user Id getting revoked from the room (required)
        :param RoomUserRemovalDetail room_user_removal_detail: Contains the date on which the users room access should be revoked
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['room_id', 'user_id', 'room_user_removal_detail', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revoke_room_user_access" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'room_id' is set
        if ('room_id' not in params) or (params['room_id'] is None):
            raise ValueError("Missing the required parameter `room_id` when calling `revoke_room_user_access`")
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params) or (params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `revoke_room_user_access`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `revoke_room_user_access`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/rooms/{roomId}/users/{userId}/revoke_access'.replace('{format}', 'json')
        path_params = {}
        if 'room_id' in params:
            path_params['roomId'] = params['room_id']
        if 'user_id' in params:
            path_params['userId'] = params['user_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'room_user_removal_detail' in params:
            body_params = params['room_user_removal_detail']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def update_picture(self, room_id, account_id, **kwargs):
        """
        Update the picture for a room.
        This endpoint supports the following content types, application/json as JSON PictureForUpdate{\"fileName\":\"string\", \"Base64Contents\":\"string\"}, multipart/formdata and any other streamed binary content type (as long as either query parameter fileName or request header ContentDisposition filename is included).
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_picture(room_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id: ID of the room the picture is for. (required)
        :param str account_id: (required)
        :return: RoomPicture
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_picture_with_http_info(room_id, account_id, **kwargs)
        else:
            (data) = self.update_picture_with_http_info(room_id, account_id, **kwargs)
            return data

    def update_picture_with_http_info(self, room_id, account_id, **kwargs):
        """
        Update the picture for a room.
        This endpoint supports the following content types, application/json as JSON PictureForUpdate{\"fileName\":\"string\", \"Base64Contents\":\"string\"}, multipart/formdata and any other streamed binary content type (as long as either query parameter fileName or request header ContentDisposition filename is included).
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_picture_with_http_info(room_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id: ID of the room the picture is for. (required)
        :param str account_id: (required)
        :return: RoomPicture
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['room_id', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_picture" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'room_id' is set
        if ('room_id' not in params) or (params['room_id'] is None):
            raise ValueError("Missing the required parameter `room_id` when calling `update_picture`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `update_picture`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/rooms/{roomId}/picture'.replace('{format}', 'json')
        path_params = {}
        if 'room_id' in params:
            path_params['roomId'] = params['room_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='RoomPicture',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def update_room_field_data(self, room_id, field_data_for_update, account_id, **kwargs):
        """
        Updates room field data.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_room_field_data(room_id, field_data_for_update, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id:  (required)
        :param FieldDataForUpdate field_data_for_update:  (required)
        :param str account_id: (required)
        :return: FieldData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_room_field_data_with_http_info(room_id, field_data_for_update, account_id, **kwargs)
        else:
            (data) = self.update_room_field_data_with_http_info(room_id, field_data_for_update, account_id, **kwargs)
            return data

    def update_room_field_data_with_http_info(self, room_id, field_data_for_update, account_id, **kwargs):
        """
        Updates room field data.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_room_field_data_with_http_info(room_id, field_data_for_update, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int room_id:  (required)
        :param FieldDataForUpdate field_data_for_update:  (required)
        :param str account_id: (required)
        :return: FieldData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['room_id', 'field_data_for_update', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_room_field_data" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'room_id' is set
        if ('room_id' not in params) or (params['room_id'] is None):
            raise ValueError("Missing the required parameter `room_id` when calling `update_room_field_data`")
        # verify the required parameter 'field_data_for_update' is set
        if ('field_data_for_update' not in params) or (params['field_data_for_update'] is None):
            raise ValueError("Missing the required parameter `field_data_for_update` when calling `update_room_field_data`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `update_room_field_data`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/rooms/{roomId}/field_data'.replace('{format}', 'json')
        path_params = {}
        if 'room_id' in params:
            path_params['roomId'] = params['room_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'field_data_for_update' in params:
            body_params = params['field_data_for_update']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='FieldData',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class FieldConfiguration(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'max_value': 'float',
        'min_value': 'float',
        'multiple_of': 'float',
        'max_length': 'int',
        'min_length': 'int',
        'pattern': 'str',
        'is_publisher': 'bool',
        'depends_on': 'list[DependsOn]',
        'options': 'list[SelectListFieldOption]'
    }

    attribute_map = {
        'max_value': 'maxValue',
        'min_value': 'minValue',
        'multiple_of': 'multipleOf',
        'max_length': 'maxLength',
        'min_length': 'minLength',
        'pattern': 'pattern',
        'is_publisher': 'isPublisher',
        'depends_on': 'dependsOn',
        'options': 'options'
    }

    def __init__(self, max_value=None, min_value=None, multiple_of=None, max_length=None, min_length=None, pattern=None, is_publisher=None, depends_on=None, options=None):  # noqa: E501
        """FieldConfiguration - a model defined in Swagger"""  # noqa: E501

        self._max_value = None
        self._min_value = None
        self._multiple_of = None
        self._max_length = None
        self._min_length = None
        self._pattern = None
        self._is_publisher = None
        self._depends_on = None
        self._options = None
        self.discriminator = None

        if max_value is not None:
            self.max_value = max_value
        if min_value is not None:
            self.min_value = min_value
        if multiple_of is not None:
            self.multiple_of = multiple_of
        if max_length is not None:
            self.max_length = max_length
        if min_length is not None:
            self.min_length = min_length
        if pattern is not None:
            self.pattern = pattern
        if is_publisher is not None:
            self.is_publisher = is_publisher
        if depends_on is not None:
            self.depends_on = depends_on
        if options is not None:
            self.options = options

    @property
    def max_value(self):
        """Gets the max_value of this FieldConfiguration.  # noqa: E501


        :return: The max_value of this FieldConfiguration.  # noqa: E501
        :rtype: float
        """
        return self._max_value

    @max_value.setter
    def max_value(self, max_value):
        """Sets the max_value of this FieldConfiguration.


        :param max_value: The max_value of this FieldConfiguration.  # noqa: E501
        :type: float
        """

        self._max_value = max_value

    @property
    def min_value(self):
        """Gets the min_value of this FieldConfiguration.  # noqa: E501


        :return: The min_value of this FieldConfiguration.  # noqa: E501
        :rtype: float
        """
        return self._min_value

    @min_value.setter
    def min_value(self, min_value):
        """Sets the min_value of this FieldConfiguration.


        :param min_value: The min_value of this FieldConfiguration.  # noqa: E501
        :type: float
        """

        self._min_value = min_value

    @property
    def multiple_of(self):
        """Gets the multiple_of of this FieldConfiguration.  # noqa: E501


        :return: The multiple_of of this FieldConfiguration.  # noqa: E501
        :rtype: float
        """
        return self._multiple_of

    @multiple_of.setter
    def multiple_of(self, multiple_of):
        """Sets the multiple_of of this FieldConfiguration.


        :param multiple_of: The multiple_of of this FieldConfiguration.  # noqa: E501
        :type: float
        """

        self._multiple_of = multiple_of

    @property
    def max_length(self):
        """Gets the max_length of this FieldConfiguration.  # noqa: E501


        :return: The max_length of this FieldConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_length

    @max_length.setter
    def max_length(self, max_length):
        """Sets the max_length of this FieldConfiguration.


        :param max_length: The max_length of this FieldConfiguration.  # noqa: E501
        :type: int
        """

        self._max_length = max_length

    @property
    def min_length(self):
        """Gets the min_length of this FieldConfiguration.  # noqa: E501


        :return: The min_length of this FieldConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._min_length

    @min_length.setter
    def min_length(self, min_length):
        """Sets the min_length of this FieldConfiguration.


        :param min_length: The min_length of this FieldConfiguration.  # noqa: E501
        :type: int
        """

        self._min_length = min_length

    @property
    def pattern(self):
        """Gets the pattern of this FieldConfiguration.  # noqa: E501


        :return: The pattern of this FieldConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        """Sets the pattern of this FieldConfiguration.


        :param pattern: The pattern of this FieldConfiguration.  # noqa: E501
        :type: str
        """

        self._pattern = pattern

    @property
    def is_publisher(self):
        """Gets the is_publisher of this FieldConfiguration.  # noqa: E501


        :return: The is_publisher of this FieldConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._is_publisher

    @is_publisher.setter
    def is_publisher(self, is_publisher):
        """Sets the is_publisher of this FieldConfiguration.


        :param is_publisher: The is_publisher of this FieldConfiguration.  # noqa: E501
        :type: bool
        """

        self._is_publisher = is_publisher

    @property
    def depends_on(self):
        """Gets the depends_on of this FieldConfiguration.  # noqa: E501


        :return: The depends_on of this FieldConfiguration.  # noqa: E501
        :rtype: list[DependsOn]
        """
        return self._depends_on

    @depends_on.setter
    def depends_on(self, depends_on):
        """Sets the depends_on of this FieldConfiguration.


        :param depends_on: The depends_on of this FieldConfiguration.  # noqa: E501
        :type: list[DependsOn]
        """

        self._depends_on = depends_on

    @property
    def options(self):
        """Gets the options of this FieldConfiguration.  # noqa: E501


        :return: The options of this FieldConfiguration.  # noqa: E501
        :rtype: list[SelectListFieldOption]
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this FieldConfiguration.


        :param options: The options of this FieldConfiguration.  # noqa: E501
        :type: list[SelectListFieldOption]
        """

        self._options = options

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FieldConfiguration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FieldConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TaskSummary(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'task_id': 'int',
        'name': 'str',
        'requires_approval': 'bool',
        'due_date_type_id': 'str',
        'due_date_offset': 'int',
        'fixed_due_date': 'datetime',
        'owner_user_id': 'int',
        'completion_date': 'datetime',
        'approval_date': 'datetime',
        'rejected_date': 'datetime',
        'created_date': 'datetime',
        'is_document_task': 'bool',
        'requires_review': 'bool'
    }

    attribute_map = {
        'task_id': 'taskId',
        'name': 'name',
        'requires_approval': 'requiresApproval',
        'due_date_type_id': 'dueDateTypeId',
        'due_date_offset': 'dueDateOffset',
        'fixed_due_date': 'fixedDueDate',
        'owner_user_id': 'ownerUserId',
        'completion_date': 'completionDate',
        'approval_date': 'approvalDate',
        'rejected_date': 'rejectedDate',
        'created_date': 'createdDate',
        'is_document_task': 'isDocumentTask',
        'requires_review': 'requiresReview'
    }

    def __init__(self, task_id=None, name=None, requires_approval=None, due_date_type_id=None, due_date_offset=None, fixed_due_date=None, owner_user_id=None, completion_date=None, approval_date=None, rejected_date=None, created_date=None, is_document_task=None, requires_review=None):  # noqa: E501
        """TaskSummary - a model defined in Swagger"""  # noqa: E501

        self._task_id = None
        self._name = None
        self._requires_approval = None
        self._due_date_type_id = None
        self._due_date_offset = None
        self._fixed_due_date = None
        self._owner_user_id = None
        self._completion_date = None
        self._approval_date = None
        self._rejected_date = None
        self._created_date = None
        self._is_document_task = None
        self._requires_review = None
        self.discriminator = None

        if task_id is not None:
            self.task_id = task_id
        if name is not None:
            self.name = name
        if requires_approval is not None:
            self.requires_approval = requires_approval
        if due_date_type_id is not None:
            self.due_date_type_id = due_date_type_id
        if due_date_offset is not None:
            self.due_date_offset = due_date_offset
        if fixed_due_date is not None:
            self.fixed_due_date = fixed_due_date
        if owner_user_id is not None:
            self.owner_user_id = owner_user_id
        if completion_date is not None:
            self.completion_date = completion_date
        if approval_date is not None:
            self.approval_date = approval_date
        if rejected_date is not None:
            self.rejected_date = rejected_date
        if created_date is not None:
            self.created_date = created_date
        if is_document_task is not None:
            self.is_document_task = is_document_task
        if requires_review is not None:
            self.requires_review = requires_review

    @property
    def task_id(self):
        """Gets the task_id of this TaskSummary.  # noqa: E501


        :return: The task_id of this TaskSummary.  # noqa: E501
        :rtype: int
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """Sets the task_id of this TaskSummary.


        :param task_id: The task_id of this TaskSummary.  # noqa: E501
        :type: int
        """

        self._task_id = task_id

    @property
    def name(self):
        """Gets the name of this TaskSummary.  # noqa: E501


        :return: The name of this TaskSummary.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TaskSummary.


        :param name: The name of this TaskSummary.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def requires_approval(self):
        """Gets the requires_approval of this TaskSummary.  # noqa: E501


        :return: The requires_approval of this TaskSummary.  # noqa: E501
        :rtype: bool
        """
        return self._requires_approval

    @requires_approval.setter
    def requires_approval(self, requires_approval):
        """Sets the requires_approval of this TaskSummary.


        :param requires_approval: The requires_approval of this TaskSummary.  # noqa: E501
        :type: bool
        """

        self._requires_approval = requires_approval

    @property
    def due_date_type_id(self):
        """Gets the due_date_type_id of this TaskSummary.  # noqa: E501


        :return: The due_date_type_id of this TaskSummary.  # noqa: E501
        :rtype: str
        """
        return self._due_date_type_id

    @due_date_type_id.setter
    def due_date_type_id(self, due_date_type_id):
        """Sets the due_date_type_id of this TaskSummary.


        :param due_date_type_id: The due_date_type_id of this TaskSummary.  # noqa: E501
        :type: str
        """

        self._due_date_type_id = due_date_type_id

    @property
    def due_date_offset(self):
        """Gets the due_date_offset of this TaskSummary.  # noqa: E501


        :return: The due_date_offset of this TaskSummary.  # noqa: E501
        :rtype: int
        """
        return self._due_date_offset

    @due_date_offset.setter
    def due_date_offset(self, due_date_offset):
        """Sets the due_date_offset of this TaskSummary.


        :param due_date_offset: The due_date_offset of this TaskSummary.  # noqa: E501
        :type: int
        """

        self._due_date_offset = due_date_offset

    @property
    def fixed_due_date(self):
        """Gets the fixed_due_date of this TaskSummary.  # noqa: E501


        :return: The fixed_due_date of this TaskSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._fixed_due_date

    @fixed_due_date.setter
    def fixed_due_date(self, fixed_due_date):
        """Sets the fixed_due_date of this TaskSummary.


        :param fixed_due_date: The fixed_due_date of this TaskSummary.  # noqa: E501
        :type: datetime
        """

        self._fixed_due_date = fixed_due_date

    @property
    def owner_user_id(self):
        """Gets the owner_user_id of this TaskSummary.  # noqa: E501


        :return: The owner_user_id of this TaskSummary.  # noqa: E501
        :rtype: int
        """
        return self._owner_user_id

    @owner_user_id.setter
    def owner_user_id(self, owner_user_id):
        """Sets the owner_user_id of this TaskSummary.


        :param owner_user_id: The owner_user_id of this TaskSummary.  # noqa: E501
        :type: int
        """

        self._owner_user_id = owner_user_id

    @property
    def completion_date(self):
        """Gets the completion_date of this TaskSummary.  # noqa: E501


        :return: The completion_date of this TaskSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._completion_date

    @completion_date.setter
    def completion_date(self, completion_date):
        """Sets the completion_date of this TaskSummary.


        :param completion_date: The completion_date of this TaskSummary.  # noqa: E501
        :type: datetime
        """

        self._completion_date = completion_date

    @property
    def approval_date(self):
        """Gets the approval_date of this TaskSummary.  # noqa: E501


        :return: The approval_date of this TaskSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._approval_date

    @approval_date.setter
    def approval_date(self, approval_date):
        """Sets the approval_date of this TaskSummary.


        :param approval_date: The approval_date of this TaskSummary.  # noqa: E501
        :type: datetime
        """

        self._approval_date = approval_date

    @property
    def rejected_date(self):
        """Gets the rejected_date of this TaskSummary.  # noqa: E501


        :return: The rejected_date of this TaskSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._rejected_date

    @rejected_date.setter
    def rejected_date(self, rejected_date):
        """Sets the rejected_date of this TaskSummary.


        :param rejected_date: The rejected_date of this TaskSummary.  # noqa: E501
        :type: datetime
        """

        self._rejected_date = rejected_date

    @property
    def created_date(self):
        """Gets the created_date of this TaskSummary.  # noqa: E501


        :return: The created_date of this TaskSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this TaskSummary.


        :param created_date: The created_date of this TaskSummary.  # noqa: E501
        :type: datetime
        """

        self._created_date = created_date

    @property
    def is_document_task(self):
        """Gets the is_document_task of this TaskSummary.  # noqa: E501


        :return: The is_document_task of this TaskSummary.  # noqa: E501
        :rtype: bool
        """
        return self._is_document_task

    @is_document_task.setter
    def is_document_task(self, is_document_task):
        """Sets the is_document_task of this TaskSummary.


        :param is_document_task: The is_document_task of this TaskSummary.  # noqa: E501
        :type: bool
        """

        self._is_document_task = is_document_task

    @property
    def requires_review(self):
        """Gets the requires_review of this TaskSummary.  # noqa: E501


        :return: The requires_review of this TaskSummary.  # noqa: E501
        :rtype: bool
        """
        return self._requires_review

    @requires_review.setter
    def requires_review(self, requires_review):
        """Sets the requires_review of this TaskSummary.


        :param requires_review: The requires_review of this TaskSummary.  # noqa: E501
        :type: bool
        """

        self._requires_review = requires_review

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TaskSummary, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaskSummary):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from .account_summary import AccountSummary
from .activity_type import ActivityType
from .api_error import ApiError
from .assignable_roles import AssignableRoles
from .classic_admin_to_invite import ClassicAdminToInvite
from .classic_agent_to_invite import ClassicAgentToInvite
from .classic_manager_permissions import ClassicManagerPermissions
from .classic_manager_to_invite import ClassicManagerToInvite
from .closing_status import ClosingStatus
from .contact_side import ContactSide
from .country import Country
from .currency import Currency
from .custom_data import CustomData
from .depends_on import DependsOn
from .designated_office import DesignatedOffice
from .designated_region import DesignatedRegion
from .document import Document
from .document_user import DocumentUser
from .document_user_for_create import DocumentUserForCreate
from .e_sign_account_role_settings import ESignAccountRoleSettings
from .e_sign_permission_profile import ESignPermissionProfile
from .e_sign_permission_profile_list import ESignPermissionProfileList
from .external_form_fill_session import ExternalFormFillSession
from .external_form_fill_session_for_create import ExternalFormFillSessionForCreate
from .field import Field
from .field_configuration import FieldConfiguration
from .field_data import FieldData
from .field_data_for_create import FieldDataForCreate
from .field_data_for_update import FieldDataForUpdate
from .field_set import FieldSet
from .financing_type import FinancingType
from .form_details import FormDetails
from .form_for_add import FormForAdd
from .form_group_summary import FormGroupSummary
from .form_group_summary_list import FormGroupSummaryList
from .form_library_summary import FormLibrarySummary
from .form_library_summary_list import FormLibrarySummaryList
from .form_summary import FormSummary
from .form_summary_list import FormSummaryList
from .global_activity_types import GlobalActivityTypes
from .global_closing_statuses import GlobalClosingStatuses
from .global_contact_sides import GlobalContactSides
from .global_countries import GlobalCountries
from .global_currencies import GlobalCurrencies
from .global_financing_types import GlobalFinancingTypes
from .global_origins_of_leads import GlobalOriginsOfLeads
from .global_property_types import GlobalPropertyTypes
from .global_room_contact_types import GlobalRoomContactTypes
from .global_seller_decision_types import GlobalSellerDecisionTypes
from .global_special_circumstance_types import GlobalSpecialCircumstanceTypes
from .global_states import GlobalStates
from .global_task_date_types import GlobalTaskDateTypes
from .global_task_responsibility_types import GlobalTaskResponsibilityTypes
from .global_task_statuses import GlobalTaskStatuses
from .global_time_zones import GlobalTimeZones
from .global_transaction_sides import GlobalTransactionSides
from .locked_out_details import LockedOutDetails
from .nullable_field_data import NullableFieldData
from .nullable_permissions import NullablePermissions
from .office import Office
from .office_for_create import OfficeForCreate
from .office_reference_count import OfficeReferenceCount
from .office_reference_count_list import OfficeReferenceCountList
from .office_summary import OfficeSummary
from .office_summary_list import OfficeSummaryList
from .origin_of_lead import OriginOfLead
from .permissions import Permissions
from .property_type import PropertyType
from .region import Region
from .region_reference_count import RegionReferenceCount
from .region_reference_count_list import RegionReferenceCountList
from .region_summary import RegionSummary
from .region_summary_list import RegionSummaryList
from .role import Role
from .role_for_create import RoleForCreate
from .role_for_update import RoleForUpdate
from .role_summary import RoleSummary
from .role_summary_list import RoleSummaryList
from .room import Room
from .room_contact_type import RoomContactType
from .room_document import RoomDocument
from .room_document_list import RoomDocumentList
from .room_folder import RoomFolder
from .room_folder_list import RoomFolderList
from .room_for_create import RoomForCreate
from .room_invite import RoomInvite
from .room_invite_response import RoomInviteResponse
from .room_picture import RoomPicture
from .room_summary import RoomSummary
from .room_summary_list import RoomSummaryList
from .room_template import RoomTemplate
from .room_templates_summary_list import RoomTemplatesSummaryList
from .room_user import RoomUser
from .room_user_for_update import RoomUserForUpdate
from .room_user_removal_detail import RoomUserRemovalDetail
from .room_user_summary import RoomUserSummary
from .room_users_result import RoomUsersResult
from .select_list_field_option import SelectListFieldOption
from .seller_decision_type import SellerDecisionType
from .special_circumstance_type import SpecialCircumstanceType
from .state import State
from .task_date_type import TaskDateType
from .task_list import TaskList
from .task_list_for_create import TaskListForCreate
from .task_list_summary import TaskListSummary
from .task_list_summary_list import TaskListSummaryList
from .task_list_template import TaskListTemplate
from .task_list_template_list import TaskListTemplateList
from .task_responsibility_type import TaskResponsibilityType
from .task_status import TaskStatus
from .task_summary import TaskSummary
from .time_zone import TimeZone
from .transaction_side import TransactionSide
from .user import User
from .user_for_update import UserForUpdate
from .user_summary import UserSummary
from .user_summary_list import UserSummaryList
from .user_to_invite import UserToInvite


# coding: utf-8

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Field(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'field_id': 'str',
        'field_definition_id': 'str',
        'title': 'str',
        'api_name': 'str',
        'type': 'str',
        'fields': 'list[Field]',
        'configuration': 'FieldConfiguration',
        'custom_data': 'CustomData'
    }

    attribute_map = {
        'field_id': 'fieldId',
        'field_definition_id': 'fieldDefinitionId',
        'title': 'title',
        'api_name': 'apiName',
        'type': 'type',
        'fields': 'fields',
        'configuration': 'configuration',
        'custom_data': 'customData'
    }

    def __init__(self, field_id=None, field_definition_id=None, title=None, api_name=None, type=None, fields=None, configuration=None, custom_data=None):  # noqa: E501
        """Field - a model defined in Swagger"""  # noqa: E501

        self._field_id = None
        self._field_definition_id = None
        self._title = None
        self._api_name = None
        self._type = None
        self._fields = None
        self._configuration = None
        self._custom_data = None
        self.discriminator = None

        if field_id is not None:
            self.field_id = field_id
        if field_definition_id is not None:
            self.field_definition_id = field_definition_id
        if title is not None:
            self.title = title
        if api_name is not None:
            self.api_name = api_name
        if type is not None:
            self.type = type
        if fields is not None:
            self.fields = fields
        if configuration is not None:
            self.configuration = configuration
        if custom_data is not None:
            self.custom_data = custom_data

    @property
    def field_id(self):
        """Gets the field_id of this Field.  # noqa: E501


        :return: The field_id of this Field.  # noqa: E501
        :rtype: str
        """
        return self._field_id

    @field_id.setter
    def field_id(self, field_id):
        """Sets the field_id of this Field.


        :param field_id: The field_id of this Field.  # noqa: E501
        :type: str
        """

        self._field_id = field_id

    @property
    def field_definition_id(self):
        """Gets the field_definition_id of this Field.  # noqa: E501


        :return: The field_definition_id of this Field.  # noqa: E501
        :rtype: str
        """
        return self._field_definition_id

    @field_definition_id.setter
    def field_definition_id(self, field_definition_id):
        """Sets the field_definition_id of this Field.


        :param field_definition_id: The field_definition_id of this Field.  # noqa: E501
        :type: str
        """

        self._field_definition_id = field_definition_id

    @property
    def title(self):
        """Gets the title of this Field.  # noqa: E501


        :return: The title of this Field.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Field.


        :param title: The title of this Field.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def api_name(self):
        """Gets the api_name of this Field.  # noqa: E501


        :return: The api_name of this Field.  # noqa: E501
        :rtype: str
        """
        return self._api_name

    @api_name.setter
    def api_name(self, api_name):
        """Sets the api_name of this Field.


        :param api_name: The api_name of this Field.  # noqa: E501
        :type: str
        """

        self._api_name = api_name

    @property
    def type(self):
        """Gets the type of this Field.  # noqa: E501


        :return: The type of this Field.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Field.


        :param type: The type of this Field.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def fields(self):
        """Gets the fields of this Field.  # noqa: E501


        :return: The fields of this Field.  # noqa: E501
        :rtype: list[Field]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """Sets the fields of this Field.


        :param fields: The fields of this Field.  # noqa: E501
        :type: list[Field]
        """

        self._fields = fields

    @property
    def configuration(self):
        """Gets the configuration of this Field.  # noqa: E501


        :return: The configuration of this Field.  # noqa: E501
        :rtype: FieldConfiguration
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this Field.


        :param configuration: The configuration of this Field.  # noqa: E501
        :type: FieldConfiguration
        """

        self._configuration = configuration

    @property
    def custom_data(self):
        """Gets the custom_data of this Field.  # noqa: E501


        :return: The custom_data of this Field.  # noqa: E501
        :rtype: CustomData
        """
        return self._custom_data

    @custom_data.setter
    def custom_data(self, custom_data):
        """Sets the custom_data of this Field.


        :param custom_data: The custom_data of this Field.  # noqa: E501
        :type: CustomData
        """

        self._custom_data = custom_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Field, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Field):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# import auth modules into client package
from .oauth import Account
from .oauth import Organization
from .oauth import Link
from .oauth import OAuth
from .oauth import OAuthToken


# coding: utf-8

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ClassicManagerToInvite(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'first_name': 'str',
        'last_name': 'str',
        'email': 'str',
        'default_office_id': 'int',
        'title_id': 'int',
        'access_level': 'str',
        'permissions': 'ClassicManagerPermissions',
        'offices': 'list[int]',
        'regions': 'list[int]',
        'e_sign_permission_profile_id': 'str'
    }

    attribute_map = {
        'first_name': 'firstName',
        'last_name': 'lastName',
        'email': 'email',
        'default_office_id': 'defaultOfficeId',
        'title_id': 'titleId',
        'access_level': 'accessLevel',
        'permissions': 'permissions',
        'offices': 'offices',
        'regions': 'regions',
        'e_sign_permission_profile_id': 'eSignPermissionProfileId'
    }

    def __init__(self, first_name=None, last_name=None, email=None, default_office_id=None, title_id=None, access_level=None, permissions=None, offices=None, regions=None, e_sign_permission_profile_id=None):  # noqa: E501
        """ClassicManagerToInvite - a model defined in Swagger"""  # noqa: E501

        self._first_name = None
        self._last_name = None
        self._email = None
        self._default_office_id = None
        self._title_id = None
        self._access_level = None
        self._permissions = None
        self._offices = None
        self._regions = None
        self._e_sign_permission_profile_id = None
        self.discriminator = None

        self.first_name = first_name
        self.last_name = last_name
        self.email = email
        self.default_office_id = default_office_id
        self.title_id = title_id
        self.access_level = access_level
        self.permissions = permissions
        if offices is not None:
            self.offices = offices
        if regions is not None:
            self.regions = regions
        if e_sign_permission_profile_id is not None:
            self.e_sign_permission_profile_id = e_sign_permission_profile_id

    @property
    def first_name(self):
        """Gets the first_name of this ClassicManagerToInvite.  # noqa: E501


        :return: The first_name of this ClassicManagerToInvite.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this ClassicManagerToInvite.


        :param first_name: The first_name of this ClassicManagerToInvite.  # noqa: E501
        :type: str
        """
        if first_name is None:
            raise ValueError("Invalid value for `first_name`, must not be `None`")  # noqa: E501

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this ClassicManagerToInvite.  # noqa: E501


        :return: The last_name of this ClassicManagerToInvite.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this ClassicManagerToInvite.


        :param last_name: The last_name of this ClassicManagerToInvite.  # noqa: E501
        :type: str
        """
        if last_name is None:
            raise ValueError("Invalid value for `last_name`, must not be `None`")  # noqa: E501

        self._last_name = last_name

    @property
    def email(self):
        """Gets the email of this ClassicManagerToInvite.  # noqa: E501


        :return: The email of this ClassicManagerToInvite.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this ClassicManagerToInvite.


        :param email: The email of this ClassicManagerToInvite.  # noqa: E501
        :type: str
        """
        if email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def default_office_id(self):
        """Gets the default_office_id of this ClassicManagerToInvite.  # noqa: E501


        :return: The default_office_id of this ClassicManagerToInvite.  # noqa: E501
        :rtype: int
        """
        return self._default_office_id

    @default_office_id.setter
    def default_office_id(self, default_office_id):
        """Sets the default_office_id of this ClassicManagerToInvite.


        :param default_office_id: The default_office_id of this ClassicManagerToInvite.  # noqa: E501
        :type: int
        """
        if default_office_id is None:
            raise ValueError("Invalid value for `default_office_id`, must not be `None`")  # noqa: E501

        self._default_office_id = default_office_id

    @property
    def title_id(self):
        """Gets the title_id of this ClassicManagerToInvite.  # noqa: E501


        :return: The title_id of this ClassicManagerToInvite.  # noqa: E501
        :rtype: int
        """
        return self._title_id

    @title_id.setter
    def title_id(self, title_id):
        """Sets the title_id of this ClassicManagerToInvite.


        :param title_id: The title_id of this ClassicManagerToInvite.  # noqa: E501
        :type: int
        """
        if title_id is None:
            raise ValueError("Invalid value for `title_id`, must not be `None`")  # noqa: E501

        self._title_id = title_id

    @property
    def access_level(self):
        """Gets the access_level of this ClassicManagerToInvite.  # noqa: E501


        :return: The access_level of this ClassicManagerToInvite.  # noqa: E501
        :rtype: str
        """
        return self._access_level

    @access_level.setter
    def access_level(self, access_level):
        """Sets the access_level of this ClassicManagerToInvite.


        :param access_level: The access_level of this ClassicManagerToInvite.  # noqa: E501
        :type: str
        """
        if access_level is None:
            raise ValueError("Invalid value for `access_level`, must not be `None`")  # noqa: E501
        allowed_values = ["Contributor", "Office", "Region", "Company", "Admin"]  # noqa: E501
        if access_level not in allowed_values:
            raise ValueError(
                "Invalid value for `access_level` ({0}), must be one of {1}"  # noqa: E501
                .format(access_level, allowed_values)
            )

        self._access_level = access_level

    @property
    def permissions(self):
        """Gets the permissions of this ClassicManagerToInvite.  # noqa: E501


        :return: The permissions of this ClassicManagerToInvite.  # noqa: E501
        :rtype: ClassicManagerPermissions
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this ClassicManagerToInvite.


        :param permissions: The permissions of this ClassicManagerToInvite.  # noqa: E501
        :type: ClassicManagerPermissions
        """
        if permissions is None:
            raise ValueError("Invalid value for `permissions`, must not be `None`")  # noqa: E501

        self._permissions = permissions

    @property
    def offices(self):
        """Gets the offices of this ClassicManagerToInvite.  # noqa: E501


        :return: The offices of this ClassicManagerToInvite.  # noqa: E501
        :rtype: list[int]
        """
        return self._offices

    @offices.setter
    def offices(self, offices):
        """Sets the offices of this ClassicManagerToInvite.


        :param offices: The offices of this ClassicManagerToInvite.  # noqa: E501
        :type: list[int]
        """

        self._offices = offices

    @property
    def regions(self):
        """Gets the regions of this ClassicManagerToInvite.  # noqa: E501


        :return: The regions of this ClassicManagerToInvite.  # noqa: E501
        :rtype: list[int]
        """
        return self._regions

    @regions.setter
    def regions(self, regions):
        """Sets the regions of this ClassicManagerToInvite.


        :param regions: The regions of this ClassicManagerToInvite.  # noqa: E501
        :type: list[int]
        """

        self._regions = regions

    @property
    def e_sign_permission_profile_id(self):
        """Gets the e_sign_permission_profile_id of this ClassicManagerToInvite.  # noqa: E501

        Required when the company is tightly bound to an eSign account; otherwise ignored.  # noqa: E501

        :return: The e_sign_permission_profile_id of this ClassicManagerToInvite.  # noqa: E501
        :rtype: str
        """
        return self._e_sign_permission_profile_id

    @e_sign_permission_profile_id.setter
    def e_sign_permission_profile_id(self, e_sign_permission_profile_id):
        """Sets the e_sign_permission_profile_id of this ClassicManagerToInvite.

        Required when the company is tightly bound to an eSign account; otherwise ignored.  # noqa: E501

        :param e_sign_permission_profile_id: The e_sign_permission_profile_id of this ClassicManagerToInvite.  # noqa: E501
        :type: str
        """

        self._e_sign_permission_profile_id = e_sign_permission_profile_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ClassicManagerToInvite, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClassicManagerToInvite):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DocumentUser(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user_id': 'int',
        'document_id': 'int',
        'name': 'str',
        'has_access': 'bool',
        'can_approve_task': 'bool',
        'can_assign_to_task_list': 'bool',
        'can_copy': 'bool',
        'can_delete': 'bool',
        'can_remove_from_task_list': 'bool',
        'can_remove_approval': 'bool',
        'can_rename': 'bool',
        'can_share': 'bool',
        'can_view_activity': 'bool'
    }

    attribute_map = {
        'user_id': 'userId',
        'document_id': 'documentId',
        'name': 'name',
        'has_access': 'hasAccess',
        'can_approve_task': 'canApproveTask',
        'can_assign_to_task_list': 'canAssignToTaskList',
        'can_copy': 'canCopy',
        'can_delete': 'canDelete',
        'can_remove_from_task_list': 'canRemoveFromTaskList',
        'can_remove_approval': 'canRemoveApproval',
        'can_rename': 'canRename',
        'can_share': 'canShare',
        'can_view_activity': 'canViewActivity'
    }

    def __init__(self, user_id=None, document_id=None, name=None, has_access=None, can_approve_task=None, can_assign_to_task_list=None, can_copy=None, can_delete=None, can_remove_from_task_list=None, can_remove_approval=None, can_rename=None, can_share=None, can_view_activity=None):  # noqa: E501
        """DocumentUser - a model defined in Swagger"""  # noqa: E501

        self._user_id = None
        self._document_id = None
        self._name = None
        self._has_access = None
        self._can_approve_task = None
        self._can_assign_to_task_list = None
        self._can_copy = None
        self._can_delete = None
        self._can_remove_from_task_list = None
        self._can_remove_approval = None
        self._can_rename = None
        self._can_share = None
        self._can_view_activity = None
        self.discriminator = None

        if user_id is not None:
            self.user_id = user_id
        if document_id is not None:
            self.document_id = document_id
        if name is not None:
            self.name = name
        if has_access is not None:
            self.has_access = has_access
        if can_approve_task is not None:
            self.can_approve_task = can_approve_task
        if can_assign_to_task_list is not None:
            self.can_assign_to_task_list = can_assign_to_task_list
        if can_copy is not None:
            self.can_copy = can_copy
        if can_delete is not None:
            self.can_delete = can_delete
        if can_remove_from_task_list is not None:
            self.can_remove_from_task_list = can_remove_from_task_list
        if can_remove_approval is not None:
            self.can_remove_approval = can_remove_approval
        if can_rename is not None:
            self.can_rename = can_rename
        if can_share is not None:
            self.can_share = can_share
        if can_view_activity is not None:
            self.can_view_activity = can_view_activity

    @property
    def user_id(self):
        """Gets the user_id of this DocumentUser.  # noqa: E501


        :return: The user_id of this DocumentUser.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this DocumentUser.


        :param user_id: The user_id of this DocumentUser.  # noqa: E501
        :type: int
        """

        self._user_id = user_id

    @property
    def document_id(self):
        """Gets the document_id of this DocumentUser.  # noqa: E501


        :return: The document_id of this DocumentUser.  # noqa: E501
        :rtype: int
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this DocumentUser.


        :param document_id: The document_id of this DocumentUser.  # noqa: E501
        :type: int
        """

        self._document_id = document_id

    @property
    def name(self):
        """Gets the name of this DocumentUser.  # noqa: E501


        :return: The name of this DocumentUser.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DocumentUser.


        :param name: The name of this DocumentUser.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def has_access(self):
        """Gets the has_access of this DocumentUser.  # noqa: E501


        :return: The has_access of this DocumentUser.  # noqa: E501
        :rtype: bool
        """
        return self._has_access

    @has_access.setter
    def has_access(self, has_access):
        """Sets the has_access of this DocumentUser.


        :param has_access: The has_access of this DocumentUser.  # noqa: E501
        :type: bool
        """

        self._has_access = has_access

    @property
    def can_approve_task(self):
        """Gets the can_approve_task of this DocumentUser.  # noqa: E501


        :return: The can_approve_task of this DocumentUser.  # noqa: E501
        :rtype: bool
        """
        return self._can_approve_task

    @can_approve_task.setter
    def can_approve_task(self, can_approve_task):
        """Sets the can_approve_task of this DocumentUser.


        :param can_approve_task: The can_approve_task of this DocumentUser.  # noqa: E501
        :type: bool
        """

        self._can_approve_task = can_approve_task

    @property
    def can_assign_to_task_list(self):
        """Gets the can_assign_to_task_list of this DocumentUser.  # noqa: E501


        :return: The can_assign_to_task_list of this DocumentUser.  # noqa: E501
        :rtype: bool
        """
        return self._can_assign_to_task_list

    @can_assign_to_task_list.setter
    def can_assign_to_task_list(self, can_assign_to_task_list):
        """Sets the can_assign_to_task_list of this DocumentUser.


        :param can_assign_to_task_list: The can_assign_to_task_list of this DocumentUser.  # noqa: E501
        :type: bool
        """

        self._can_assign_to_task_list = can_assign_to_task_list

    @property
    def can_copy(self):
        """Gets the can_copy of this DocumentUser.  # noqa: E501


        :return: The can_copy of this DocumentUser.  # noqa: E501
        :rtype: bool
        """
        return self._can_copy

    @can_copy.setter
    def can_copy(self, can_copy):
        """Sets the can_copy of this DocumentUser.


        :param can_copy: The can_copy of this DocumentUser.  # noqa: E501
        :type: bool
        """

        self._can_copy = can_copy

    @property
    def can_delete(self):
        """Gets the can_delete of this DocumentUser.  # noqa: E501


        :return: The can_delete of this DocumentUser.  # noqa: E501
        :rtype: bool
        """
        return self._can_delete

    @can_delete.setter
    def can_delete(self, can_delete):
        """Sets the can_delete of this DocumentUser.


        :param can_delete: The can_delete of this DocumentUser.  # noqa: E501
        :type: bool
        """

        self._can_delete = can_delete

    @property
    def can_remove_from_task_list(self):
        """Gets the can_remove_from_task_list of this DocumentUser.  # noqa: E501


        :return: The can_remove_from_task_list of this DocumentUser.  # noqa: E501
        :rtype: bool
        """
        return self._can_remove_from_task_list

    @can_remove_from_task_list.setter
    def can_remove_from_task_list(self, can_remove_from_task_list):
        """Sets the can_remove_from_task_list of this DocumentUser.


        :param can_remove_from_task_list: The can_remove_from_task_list of this DocumentUser.  # noqa: E501
        :type: bool
        """

        self._can_remove_from_task_list = can_remove_from_task_list

    @property
    def can_remove_approval(self):
        """Gets the can_remove_approval of this DocumentUser.  # noqa: E501


        :return: The can_remove_approval of this DocumentUser.  # noqa: E501
        :rtype: bool
        """
        return self._can_remove_approval

    @can_remove_approval.setter
    def can_remove_approval(self, can_remove_approval):
        """Sets the can_remove_approval of this DocumentUser.


        :param can_remove_approval: The can_remove_approval of this DocumentUser.  # noqa: E501
        :type: bool
        """

        self._can_remove_approval = can_remove_approval

    @property
    def can_rename(self):
        """Gets the can_rename of this DocumentUser.  # noqa: E501


        :return: The can_rename of this DocumentUser.  # noqa: E501
        :rtype: bool
        """
        return self._can_rename

    @can_rename.setter
    def can_rename(self, can_rename):
        """Sets the can_rename of this DocumentUser.


        :param can_rename: The can_rename of this DocumentUser.  # noqa: E501
        :type: bool
        """

        self._can_rename = can_rename

    @property
    def can_share(self):
        """Gets the can_share of this DocumentUser.  # noqa: E501


        :return: The can_share of this DocumentUser.  # noqa: E501
        :rtype: bool
        """
        return self._can_share

    @can_share.setter
    def can_share(self, can_share):
        """Sets the can_share of this DocumentUser.


        :param can_share: The can_share of this DocumentUser.  # noqa: E501
        :type: bool
        """

        self._can_share = can_share

    @property
    def can_view_activity(self):
        """Gets the can_view_activity of this DocumentUser.  # noqa: E501


        :return: The can_view_activity of this DocumentUser.  # noqa: E501
        :rtype: bool
        """
        return self._can_view_activity

    @can_view_activity.setter
    def can_view_activity(self, can_view_activity):
        """Sets the can_view_activity of this DocumentUser.


        :param can_view_activity: The can_view_activity of this DocumentUser.  # noqa: E501
        :type: bool
        """

        self._can_view_activity = can_view_activity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocumentUser, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocumentUser):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
